#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hiedb
version:              0.3.0.1
visibility:           public
id:                   hiedb-0.3.0.1-3BijloAy8YKIdbj4b6ZyJj
key:                  hiedb-0.3.0.1-3BijloAy8YKIdbj4b6ZyJj
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  24986bbb87faa2b84518c01f57da1909
exposed:              True
exposed-modules:
    HieDb HieDb.Create HieDb.Dump HieDb.Html HieDb.Query HieDb.Run
    HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hiedb-0.3.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hiedb-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hiedb-0.3.0.1
hs-libraries:         HShiedb-0.3.0.1-3BijloAy8YKIdbj4b6ZyJj
depends:
    algebraic-graphs-0.5-6Mitx71bn696mws0hSew9y
    ansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i array-0.5.4.0
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    directory-1.3.6.0 extra-1.7.9-4atxCqewDRnKsFBrL9ak4x
    filepath-1.4.2.1 ghc-8.10.5
    hie-compat-0.2.0.0-2uJ4eLp19m9HNuq0NixVNO
    lucid-2.9.12.1-9oIuMQbP4r48YxtDtY8LUx mtl-2.2.2
    optparse-applicative-0.16.1.0-ARX6qDeExVWDKYrQ55nL8e
    sqlite-simple-0.4.18.0-K4ValKu8jlY3d8ZtmQxp1p text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

